==> rust_socketio-0.2.1.crate: rust_socketio-0.2.1/CONTRIBUTING.md <==
# Introduction

Contributions to this project are welcome! 

This project is still being developed, our goal is to have a well-designed
thought-out project, so when you make a contribution, please think in those
terms. That is:

- For code:
    - Is the contribution in the scope of this crate?
    - Is it well documented?
    - Is it well tested?
- For documentation:
    - Is it clear and well-written?
    - Can others understand it easily?
- For bugs:
    - Does it test functionality of this crate?
    - Do you have a minimal crate that causes the issue that we can use and test?
- For feature requests:
    - Is the request within the scope of this crate?
    - Is the request clearly explained?

## Licensing and other property rights.

All contributions that are made to this project are only accepted under the
terms in the [LICENSE](LICENSE) file. That is, if you contribute to this
project, you are certifying that you have all the necessary rights to make the
contribution under the terms of the [LICENSE](LICENSE) file, and you are in fact
licensing them to this project and anyone that uses this project under the terms
in the [LICENSE](LICENSE) file.

## Misc
- We are looking at adopting the [conventional commits 1.0](https://www.conventionalcommits.org/en/v1.0.0/) standard.
    - This woould make it easier for us to use tools like [jilu](https://crates.io/crates/jilu) to create change logs.
    - Read [keep a changelog](https://keepachangelog.com/en/1.0.0/) for more information.

==> rust_socketio-0.2.2.crate: rust_socketio-0.2.2/CONTRIBUTING.md <==
# Introduction

Contributions to this project are welcome! 

This project is still being developed, our goal is to have a well-designed
thought-out project, so when you make a contribution, please think in those
terms. That is:

- For code:
    - Is the contribution in the scope of this crate?
    - Is it well documented?
    - Is it well tested?
- For documentation:
    - Is it clear and well-written?
    - Can others understand it easily?
- For bugs:
    - Does it test functionality of this crate?
    - Do you have a minimal crate that causes the issue that we can use and test?
- For feature requests:
    - Is the request within the scope of this crate?
    - Is the request clearly explained?

## Licensing and other property rights.

All contributions that are made to this project are only accepted under the
terms in the [LICENSE](LICENSE) file. That is, if you contribute to this
project, you are certifying that you have all the necessary rights to make the
contribution under the terms of the [LICENSE](LICENSE) file, and you are in fact
licensing them to this project and anyone that uses this project under the terms
in the [LICENSE](LICENSE) file.

## Misc
- We are looking at adopting the [conventional commits 1.0](https://www.conventionalcommits.org/en/v1.0.0/) standard.
    - This would make it easier for us to use tools like [jilu](https://crates.io/crates/jilu) to create change logs.
    - Read [keep a changelog](https://keepachangelog.com/en/1.0.0/) for more information.
